@@ -1,9 +1,7 @@
-// Author: Derek Barnett
+#ifndef PBBAM_MOVEAPPEND_H
+#define PBBAM_MOVEAPPEND_H
 
-#ifndef MOVEAPPEND_H
-#define MOVEAPPEND_H
-
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <iterator>
 #include <utility>
@@ -18,7 +16,7 @@ namespace BAM {
 /// \param[in,out] dst  Output vector that will be appended to
 ///
 template <typename T>
-inline void MoveAppend(std::vector<T>& src, std::vector<T>& dst) noexcept
+void MoveAppend(std::vector<T>& src, std::vector<T>& dst) noexcept
 {
     if (dst.empty()) {
         dst = std::move(src);
@@ -35,7 +33,7 @@ inline void MoveAppend(std::vector<T>& src, std::vector<T>& dst) noexcept
 /// \param[in,out] dst  Output vector that will be appended to
 ///
 template <typename T>
-inline void MoveAppend(std::vector<T>&& src, std::vector<T>& dst) noexcept
+void MoveAppend(std::vector<T>&& src, std::vector<T>& dst) noexcept
 {
     if (dst.empty()) {
         dst = std::move(src);
@@ -49,4 +47,4 @@ inline void MoveAppend(std::vector<T>&& src, std::vector<T>& dst) noexcept
 }  // namespace BAM
 }  // namespace PacBio
 
-#endif  // MOVEAPPEND_H
+#endif  // PBBAM_MOVEAPPEND_H
